@@ -41,6 +41,7 @@
 #define S_IRCD		6667
 #define S_XWIN		6000
 #define S_PROXY		8080
+#define S_BDTRINOO	27665
 #define SU_NBNAME	137
 #define SU_NFS		2049
 #define SU_BO		31337
@@ -48,11 +49,14 @@
 #define R_NFS		100003
 #define R_YPSERV	100004
 #define R_MOUNTD	100005
+#define R_WALLD		100008
 #define R_NLOCK		100021
 #define R_STATUS	100024
 #define R_BOOTPD	100026
 #define R_TTDB		100083
 #define R_CMSD		100086
+#define R_LISTEN	100099
+#define R_SADMIND	100232
 #define R_NIS		100300
 #define R_AMD		300019
 
